summaryrefslogtreecommitdiffstats
path: root/src/htmlexporter.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/htmlexporter.cpp')
-rw-r--r--src/htmlexporter.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/htmlexporter.cpp b/src/htmlexporter.cpp
index 4936454..762abe5 100644
--- a/src/htmlexporter.cpp
+++ b/src/htmlexporter.cpp
@@ -47,7 +47,7 @@ HTMLExporter::HTMLExporter(Basket *basket)
KConfig *config = KGlobal::config();
config->setGroup("Export to HTML");
TQString folder = config->readEntry("lastFolder", TQDir::homeDirPath()) + "/";
- TQString url = folder + TQString(basket->basketName()).tqreplace("/", "_") + ".html";
+ TQString url = folder + TQString(basket->basketName()).replace("/", "_") + ".html";
// Ask a file name & path to the user:
TQString filter = "*.html *.htm|" + i18n("HTML Documents") + "\n*|" + i18n("All Files");
@@ -525,8 +525,8 @@ TQString HTMLExporter::copyIcon(const TQString &iconName, int size)
return "";
// Sometimes icon can be "favicons/www.kde.org", we replace the '/' with a '_'
- TQString fileName = iconName; // TQString::tqreplace() isn't const, so I must copy the string before
- fileName = "ico" + TQString::number(size) + "_" + fileName.tqreplace("/", "_") + ".png";
+ TQString fileName = iconName; // TQString::replace() isn't const, so I must copy the string before
+ fileName = "ico" + TQString::number(size) + "_" + fileName.replace("/", "_") + ".png";
TQString fullPath = iconsFolderPath + fileName;
if (!TQFile::exists(fullPath))
DesktopIcon(iconName, size).save(fullPath, "PNG");